==> qtjambi-help-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiHelp/QHelpSearchResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpsearchengine.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpSearchResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpSearchResult")
    QHelpSearchResult *_ptr = reinterpret_cast<QHelpSearchResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHelpSearchResult()
void __qt_construct_QHelpSearchResult(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchResult()")
    Q_UNUSED(__java_arguments)
    QHelpSearchResult *__qt_this = new(__qtjambi_ptr) QHelpSearchResult();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QHelpSearchResult::QHelpSearchResult()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_initialize_1native__Lio_qt_help_QHelpSearchResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchResult::QHelpSearchResult()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchResult, sizeof(QHelpSearchResult), typeid(QHelpSearchResult), false, &deleter_QHelpSearchResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHelpSearchResult(QHelpSearchResult)
void __qt_construct_QHelpSearchResult_cref_QHelpSearchResult(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchResult(QHelpSearchResult)")
    jobject other0 = __java_arguments[0].l;
    const QHelpSearchResult& __qt_other0 = qtjambi_cast<const QHelpSearchResult& >(__jni_env, other0);
    QHelpSearchResult *__qt_this = new(__qtjambi_ptr) QHelpSearchResult(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHelpSearchResult::QHelpSearchResult(QHelpSearchResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_initialize_1native__Lio_qt_help_QHelpSearchResult_2Lio_qt_help_QHelpSearchResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchResult::QHelpSearchResult(QHelpSearchResult)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchResult_cref_QHelpSearchResult, sizeof(QHelpSearchResult), typeid(QHelpSearchResult), false, &deleter_QHelpSearchResult, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHelpSearchResult(QUrl,QString,QString)
void __qt_construct_QHelpSearchResult_cref_QUrl_cref_QString_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchResult(QUrl,QString,QString)")
    jobject url0 = __java_arguments[0].l;
    const QUrl& __qt_url0 = qtjambi_cast<const QUrl& >(__jni_env, url0);
    jstring title1 = static_cast<jstring>(__java_arguments[1].l);
    QString  __qt_title1 = qtjambi_cast<QString>(__jni_env, title1);
    jstring snippet2 = static_cast<jstring>(__java_arguments[2].l);
    QString  __qt_snippet2 = qtjambi_cast<QString>(__jni_env, snippet2);
    QHelpSearchResult *__qt_this = new(__qtjambi_ptr) QHelpSearchResult(__qt_url0, __qt_title1, __qt_snippet2);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHelpSearchResult::QHelpSearchResult(QUrl,QString,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_initialize_1native__Lio_qt_help_QHelpSearchResult_2Lio_qt_core_QUrl_2Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject url0,
 jstring title1,
 jstring snippet2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchResult::QHelpSearchResult(QUrl,QString,QString)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = url0;
        arguments[1].l = title1;
        arguments[2].l = snippet2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchResult_cref_QUrl_cref_QString_cref_QString, sizeof(QHelpSearchResult), typeid(QHelpSearchResult), false, &deleter_QHelpSearchResult, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QHelpSearchResult
void __qt_destruct_QHelpSearchResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpSearchResult")
    reinterpret_cast<QHelpSearchResult*>(ptr)->~QHelpSearchResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpSearchResult::operator=(QHelpSearchResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_assign_1native_1cref_1QHelpSearchResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::operator=(QHelpSearchResult)", __qt_this)
        const QHelpSearchResult& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHelpSearchResult>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpSearchResult::snippet()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_snippet_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::snippet()const", __qt_this)
        QString __qt_return_value = __qt_this->snippet();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpSearchResult::title()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_title_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::title()const", __qt_this)
        QString __qt_return_value = __qt_this->title();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpSearchResult::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpSearchResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpSearchResult>("QHelpSearchResult", "io/qt/help/QHelpSearchResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpSearchResult, {
        ConstructorInfo(&__qt_construct_QHelpSearchResult, nullptr)
       ,ConstructorInfo(&__qt_construct_QHelpSearchResult_cref_QHelpSearchResult, "Lio/qt/help/QHelpSearchResult;")
       ,ConstructorInfo(&__qt_construct_QHelpSearchResult_cref_QUrl_cref_QString_cref_QString, "Lio/qt/core/QUrl;Ljava/lang/String;Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpSearchResult);
    registerMetaType<QHelpSearchResult>("QHelpSearchResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiHelp/QHelpSearchResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpsearchengine.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpSearchResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpSearchResult")
    QHelpSearchResult *_ptr = reinterpret_cast<QHelpSearchResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHelpSearchResult()
void __qt_construct_QHelpSearchResult_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchResult()")
    Q_UNUSED(__java_arguments)
    QHelpSearchResult *__qt_this = new(__qtjambi_ptr) QHelpSearchResult();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHelpSearchResult(QHelpSearchResult)
void __qt_construct_QHelpSearchResult_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchResult(QHelpSearchResult)")
    jobject other0 = __java_arguments[0].l;
    const QHelpSearchResult& __qt_other0 = qtjambi_cast<const QHelpSearchResult& >(__jni_env, other0);
    QHelpSearchResult *__qt_this = new(__qtjambi_ptr) QHelpSearchResult(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QHelpSearchResult(QUrl,QString,QString)
void __qt_construct_QHelpSearchResult_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchResult(QUrl,QString,QString)")
    jobject url0 = __java_arguments[0].l;
    const QUrl& __qt_url0 = qtjambi_cast<const QUrl& >(__jni_env, url0);
    jstring title1 = static_cast<jstring>(__java_arguments[1].l);
    QString  __qt_title1 = qtjambi_cast<QString>(__jni_env, title1);
    jstring snippet2 = static_cast<jstring>(__java_arguments[2].l);
    QString  __qt_snippet2 = qtjambi_cast<QString>(__jni_env, snippet2);
    QHelpSearchResult *__qt_this = new(__qtjambi_ptr) QHelpSearchResult(__qt_url0, __qt_title1, __qt_snippet2);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QHelpSearchResult
void __qt_destruct_QHelpSearchResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpSearchResult")
    reinterpret_cast<QHelpSearchResult*>(ptr)->~QHelpSearchResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpSearchResult::QHelpSearchResult()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_initialize_1native__Lio_qt_help_QHelpSearchResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchResult::QHelpSearchResult()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchResult_0, sizeof(QHelpSearchResult), typeid(QHelpSearchResult), false, &deleter_QHelpSearchResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpSearchResult::QHelpSearchResult(QHelpSearchResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_initialize_1native__Lio_qt_help_QHelpSearchResult_2Lio_qt_help_QHelpSearchResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchResult::QHelpSearchResult(QHelpSearchResult)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchResult_1, sizeof(QHelpSearchResult), typeid(QHelpSearchResult), false, &deleter_QHelpSearchResult, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpSearchResult::QHelpSearchResult(QUrl,QString,QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_initialize_1native__Lio_qt_help_QHelpSearchResult_2Lio_qt_core_QUrl_2Ljava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject url0,
 jstring title1,
 jstring snippet2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchResult::QHelpSearchResult(QUrl,QString,QString)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = url0;
        arguments[1].l = title1;
        arguments[2].l = snippet2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchResult_2, sizeof(QHelpSearchResult), typeid(QHelpSearchResult), false, &deleter_QHelpSearchResult, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpSearchResult::operator=(QHelpSearchResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_assign_1native_1cref_1QHelpSearchResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::operator=(QHelpSearchResult)", __qt_this)
        const QHelpSearchResult& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QHelpSearchResult>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpSearchResult::snippet()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_snippet_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::snippet()const", __qt_this)
        QString __qt_return_value = __qt_this->snippet();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpSearchResult::title()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_title_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::title()const", __qt_this)
        QString __qt_return_value = __qt_this->title();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHelpSearchResult::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpSearchResult::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpSearchResult *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpSearchResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpSearchResult>("QHelpSearchResult", "io/qt/help/QHelpSearchResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpSearchResult, {
        ConstructorInfo(&__qt_construct_QHelpSearchResult_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHelpSearchResult_1, "Lio/qt/help/QHelpSearchResult;")
       ,ConstructorInfo(&__qt_construct_QHelpSearchResult_2, "Lio/qt/core/QUrl;Ljava/lang/String;Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpSearchResult);
    registerMetaType<QHelpSearchResult>("QHelpSearchResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
